@@ -18,20 +18,20 @@
  *  along with this program; if not, write to the Free Software
  */
 #include <dcopclient.h>
-#include <kcmdlineargs.h>
+#include <tdecmdlineargs.h>
 #include <KoApplication.h>
 
 #include "ui/kis_aboutdata.h"
 
-static const KCmdLineOptions options[] = {
+static const TDECmdLineOptions options[] = {
     { "+[file(s)]", I18N_NOOP("File(s) or URL(s) to open"), 0 },
-    KCmdLineLastOption
+    TDECmdLineLastOption
 };
 
 extern "C" KRITA_EXPORT int kdemain(int argc, char **argv)
 {
-    KCmdLineArgs::init(argc, argv, newChalkAboutData());
-    KCmdLineArgs::addCmdLineOptions(options);
+    TDECmdLineArgs::init(argc, argv, newChalkAboutData());
+    TDECmdLineArgs::addCmdLineOptions(options);
 
     KoApplication app;
 
