@@ -26,9 +26,9 @@
 #include <tqlayout.h>
 #include <tqrect.h>
 
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 
 #include "kis_global.h"
@@ -571,7 +571,7 @@ void KisToolCurve::slotSetAction(int action) {
 TQWidget* KisToolCurve::createSelectionOptionWidget(TQWidget* parent)
 {
     m_optWidget = new KisSelectionOptions(parent, m_subject);
-    Q_CHECK_PTR(m_optWidget);
+    TQ_CHECK_PTR(m_optWidget);
     m_optWidget->setCaption(m_UIName);
 
     connect (m_optWidget, TQT_SIGNAL(actionChanged(int)), this, TQT_SLOT(slotSetAction(int)));
