@@ -29,9 +29,9 @@
 #include <tqapplication.h>
 
 #include <kdebug.h>
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kcommand.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <knuminput.h>
 
 #include <kis_global.h>
@@ -860,7 +860,7 @@ TQWidget* KisToolTransform::createOptionWidget(TQWidget* parent)
 {
 
     m_optWidget = new WdgToolTransform(parent);
-    Q_CHECK_PTR(m_optWidget);
+    TQ_CHECK_PTR(m_optWidget);
 
     m_optWidget->cmbFilter->clear();
     m_optWidget->cmbFilter->setIDList(KisFilterStrategyRegistry::instance()->listKeys());
@@ -894,19 +894,19 @@ TQWidget* KisToolTransform::optionWidget()
     return m_optWidget;
 }
 
-void KisToolTransform::setup(KActionCollection *collection)
+void KisToolTransform::setup(TDEActionCollection *collection)
 {
-    m_action = static_cast<KRadioAction *>(collection->action(name()));
+    m_action = static_cast<TDERadioAction *>(collection->action(name()));
 
     if (m_action == 0) {
-        m_action = new KRadioAction(i18n("&Transform"),
+        m_action = new TDERadioAction(i18n("&Transform"),
                         "tool_transform",
                         0,
                         this,
                         TQT_SLOT(activate()),
                         collection,
                         name());
-        Q_CHECK_PTR(m_action);
+        TQ_CHECK_PTR(m_action);
         m_action->setToolTip(i18n("Transform a layer or a selection"));
         m_action->setExclusiveGroup("tools");
         m_ownAction = true;
