@@ -37,8 +37,8 @@
 #include <tqdom.h>
 
 #include <kdebug.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 
 #include <KoGlobal.h>
 #include <KoStore.h>
