@@ -34,7 +34,7 @@ using namespace KexiDB;
 
 unsigned int pqxxSqlCursor_trans_num=0; //!< debug helper
 
-static TQByteArray pgsqlByteaToByteArray(const pqxx::result::field& r)
+static TQByteArray pgsqlByteaToByteArray(const PQXX_FIELD_CLASS& r)
 {
 	return KexiDB::pgsqlByteaToByteArray(r.c_str(), r.size());
 }
@@ -243,7 +243,7 @@ TQVariant pqxxSqlCursor::pValue(uint pos)const
 		}
 		else if (f->typeGroup() == Field::BLOBGroup)
 		{
-//			pqxx::result::field r = (*m_res)[at()][pos];
+//			PQXX_FIELD_CLASS r = (*m_res)[at()][pos];
 //			kdDebug() << r.name() << ", " << r.c_str() << ", " << r.type() << ", " << r.size() << endl;
 			return ::pgsqlByteaToByteArray((*m_res)[at()][pos]);
 		}
