@@ -21,7 +21,7 @@
 #ifndef KEXIMAINWINDOWIMPL_H
 #define KEXIMAINWINDOWIMPL_H
 
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include "core/keximainwindow.h"
 #include "core/kexiguimsghandler.h"
 
@@ -45,17 +45,17 @@ namespace KexiPart {
 class KEXIMAIN_EXPORT KexiMainWindowImpl : public KexiMainWindow, public KexiGUIMessageHandler
 {
 	Q_OBJECT
-  TQ_OBJECT
+  
 
 	public:
 		/*! Creates an empty mainwindow. */
 		KexiMainWindowImpl();
 		virtual ~KexiMainWindowImpl();
 
-		/*! Used by the main kexi routine. Creates a new Kexi main window and a new KApplication object.
+		/*! Used by the main kexi routine. Creates a new Kexi main window and a new TDEApplication object.
 		 kdemain() has to destroy the latter on exit.
 		 \return result 1 on error and 0 on success (the result can be used as a result of kdemain()) */
-		static int create(int argc, char *argv[], KAboutData* aboutdata = 0);
+		static int create(int argc, char *argv[], TDEAboutData* aboutdata = 0);
 
 		//! \return KexiMainWindowImpl singleton (if it is instantiated)
 		static KexiMainWindowImpl* self() { return dynamic_cast<KexiMainWindowImpl*>(tqApp->mainWidget()); }
@@ -91,7 +91,7 @@ class KEXIMAIN_EXPORT KexiMainWindowImpl : public KexiMainWindow, public KexiGUI
 		virtual TQPopupMenu* findPopupMenu(const char *popupName);
 
 		/*! Implemented for KexiMainWindow. */
-		virtual KActionPtrList allActions() const;
+		virtual TDEActionPtrList allActions() const;
 
 		/*! \return currently active dialog (window) od 0 if there is no active dialog. 
 		 Implemented for KexiMainWindow. */
@@ -106,9 +106,9 @@ class KEXIMAIN_EXPORT KexiMainWindowImpl : public KexiMainWindow, public KexiGUI
 		virtual int generatePrivateID();
 
 		/*! Reimplemented */
-		virtual void readProperties(KConfig *config);
-		virtual void saveProperties(KConfig *config);
-		virtual void saveGlobalProperties( KConfig* sessionConfig );
+		virtual void readProperties(TDEConfig *config);
+		virtual void saveProperties(TDEConfig *config);
+		virtual void saveGlobalProperties( TDEConfig* sessionConfig );
 
 	public slots:
 		/*! Inherited from KMdiMainFrm: we need to do some tasks before child is closed.
@@ -303,8 +303,8 @@ class KEXIMAIN_EXPORT KexiMainWindowImpl : public KexiMainWindow, public KexiGUI
 		/*! Updates application's caption - also shows project's name. */
 		void updateAppCaption();
 
-		void restoreWindowConfiguration(KConfig *config);
-		void storeWindowConfiguration(KConfig *config);
+		void restoreWindowConfiguration(TDEConfig *config);
+		void storeWindowConfiguration(TDEConfig *config);
 
 		virtual bool queryClose();
 		virtual bool queryExit();
