@@ -40,11 +40,11 @@
 #include <kexidbshortcutfile.h>
 
 #include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kmimetype.h>
-#include <kmessagebox.h>
-#include <kcmdlineargs.h>
-#include <kdeversion.h>
+#include <tdemessagebox.h>
+#include <tdecmdlineargs.h>
+#include <tdeversion.h>
 #include <kprogress.h>
 #include <ktextedit.h>
 #include <kstaticdeleter.h>
@@ -166,7 +166,7 @@ KexiDBPasswordDialog::KexiDBPasswordDialog(TQWidget *parent, KexiDB::ConnectionD
 			this, TQT_SLOT(slotShowConnectionDetails()) );
 		setButtonText(KDialogBase::User1, i18n("&Details")+ " >>");
 	}
-	setButtonOK(KGuiItem(i18n("&Open"), "fileopen"));
+	setButtonOK(KGuiItem(i18n("&Open"), "document-open"));
 }
 
 KexiDBPasswordDialog::~KexiDBPasswordDialog()
@@ -206,7 +206,7 @@ KexiStartupHandler::~KexiStartupHandler()
 	delete d;
 }
 
-bool KexiStartupHandler::getAutoopenObjects(KCmdLineArgs *args, const TQCString &action_name)
+bool KexiStartupHandler::getAutoopenObjects(TDECmdLineArgs *args, const TQCString &action_name)
 {
 	QCStringList list = args->getOptionList(action_name);
 	QCStringList::ConstIterator it;
@@ -268,7 +268,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 {
 	m_action = DoNothing;
 //	d->showConnectionDetailsExecuted = false;
-	KCmdLineArgs *args = KCmdLineArgs::parsedArgs(0);
+	TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs(0);
 	if (!args)
 		return true;
 
@@ -381,7 +381,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 		m_action = Exit;
 	}
 
-//TODO: add option for non-gui; integrate with KWallet; 
+//TODO: add option for non-gui; integrate with TDEWallet; 
 //      move to static KexiProject method
 	if (!fileDriverSelected && !cdata.driverName.isEmpty() && cdata.password.isEmpty()) {
 
