@@ -22,12 +22,12 @@
 #include <kdebug.h>
 #include <kgenericfactory.h>
 #include <kdialogbase.h>
-#include <klistview.h>
+#include <tdelistview.h>
 #include <ktabwidget.h>
 #include <kiconloader.h>
 #include <kcombobox.h>
-#include <kapplication.h>
-#include <kconfig.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
 
 #include <kexiviewbase.h>
 #include <keximainwindow.h>
@@ -127,7 +127,7 @@ KFormDesigner::WidgetLibrary* KexiFormPart::library()
 }
 
 #if 0
-void KexiFormPart::initPartActions(KActionCollection *collection)
+void KexiFormPart::initPartActions(TDEActionCollection *collection)
 {
 //this is automatic? -no
 //create child guicilent: guiClient()->setXMLFile("kexidatatableui.rc");
@@ -139,12 +139,12 @@ void KexiFormPart::initPartActions(KActionCollection *collection)
 //js	m_manager->createActions(collection, 0);
 }
 
-void KexiFormPart::initInstanceActions( int mode, KActionCollection *col )
+void KexiFormPart::initInstanceActions( int mode, TDEActionCollection *col )
 {
 	if (mode==Kexi::DesignViewMode) {
 		KFormDesigner::FormManager::self()->createActions(col, 0);
-		new KAction(i18n("Edit Tab Order..."), "tab_order", KShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(editTabOrder()), col, "taborder");
-		new KAction(i18n("Adjust Size"), "viewmagfit", KShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(ajustWidgetSize()), col, "adjust");
+		new TDEAction(i18n("Edit Tab Order..."), "tab_order", TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(editTabOrder()), col, "taborder");
+		new TDEAction(i18n("Adjust Size"), "zoom-fit-best", TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(ajustWidgetSize()), col, "adjust");
 	}
 	//TODO
 }
@@ -152,7 +152,7 @@ void KexiFormPart::initInstanceActions( int mode, KActionCollection *col )
 
 void KexiFormPart::initPartActions()
 {
-//	new KAction(i18n("Show Form UI Code"), "show_form_ui", CTRL+Key_U, m_manager, TQT_SLOT(showFormUICode()),
+//	new TDEAction(i18n("Show Form UI Code"), "show_form_ui", CTRL+Key_U, m_manager, TQT_SLOT(showFormUICode()),
 //		guiClient()->actionCollection(), "show_form_ui");
 }
 
@@ -161,27 +161,27 @@ void KexiFormPart::initInstanceActions()
 #ifdef KEXI_DEBUG_GUI
 	kapp->config()->setGroup("General");
 	if (kapp->config()->readBoolEntry("showInternalDebugger", false)) {
-		new KAction(i18n("Show Form UI Code"), "compfile", 
+		new TDEAction(i18n("Show Form UI Code"), "compfile", 
 			CTRL+Key_U, KFormDesigner::FormManager::self(), TQT_SLOT(showFormUICode()),
 			actionCollectionForMode(Kexi::DesignViewMode), "show_form_ui");
 	}
 #endif
 
-	KActionCollection *col = actionCollectionForMode(Kexi::DesignViewMode);
+	TDEActionCollection *col = actionCollectionForMode(Kexi::DesignViewMode);
 	KFormDesigner::FormManager::self()->createActions( library(), col, (KXMLGUIClient*)col->parentGUIClient() ); //guiClient() );
 
 	//connect actions provided by widget factories
 	connect( col->action("widget_assign_action"), TQT_SIGNAL(activated()), this, TQT_SLOT(slotAssignAction()));
 
-	createSharedAction(Kexi::DesignViewMode, i18n("Clear Widget Contents"), "editclear", 0, "formpart_clear_contents");
+	createSharedAction(Kexi::DesignViewMode, i18n("Clear Widget Contents"), "edit-clear", 0, "formpart_clear_contents");
 	createSharedAction(Kexi::DesignViewMode, i18n("Edit Tab Order..."), "tab_order", 0, "formpart_taborder");
 //TODO	createSharedAction(Kexi::DesignViewMode, i18n("Edit Pixmap Collection"), "icons", 0, "formpart_pixmap_collection");
 //TODO	createSharedAction(Kexi::DesignViewMode, i18n("Edit Form Connections"), "connections", 0, "formpart_connections");
 
 //	KFormDesigner::CreateLayoutCommand
 
-	KAction *action = createSharedAction(Kexi::DesignViewMode, i18n("Layout Widgets"), "", 0, "formpart_layout_menu", "KActionMenu");
-	KActionMenu *menu = static_cast<KActionMenu*>(action);
+	TDEAction *action = createSharedAction(Kexi::DesignViewMode, i18n("Layout Widgets"), "", 0, "formpart_layout_menu", "TDEActionMenu");
+	TDEActionMenu *menu = static_cast<TDEActionMenu*>(action);
 
 	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("&Horizontally"),
 		TQString(), 0, "formpart_layout_hbox"));
@@ -206,19 +206,19 @@ void KexiFormPart::initInstanceActions()
 	createSharedAction(Kexi::DesignViewMode, i18n("Send Widget to Back"), "lower", 0, "formpart_format_lower");
 
 #ifndef KEXI_NO_UNFINISHED
-	action = createSharedAction(Kexi::DesignViewMode, i18n("Other Widgets"), "", 0, "other_widgets_menu", "KActionMenu");
+	action = createSharedAction(Kexi::DesignViewMode, i18n("Other Widgets"), "", 0, "other_widgets_menu", "TDEActionMenu");
 #endif
 
-	action = createSharedAction(Kexi::DesignViewMode, i18n("Align Widgets Position"), "aoleft", 0, "formpart_align_menu", "KActionMenu");
-	menu = static_cast<KActionMenu*>(action);
+	action = createSharedAction(Kexi::DesignViewMode, i18n("Align Widgets Position"), "aoleft", 0, "formpart_align_menu", "TDEActionMenu");
+	menu = static_cast<TDEActionMenu*>(action);
 	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("To Left"), "aoleft", 0, "formpart_align_to_left") );
 	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("To Right"), "aoright", 0, "formpart_align_to_right") );
 	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("To Top"), "aotop", 0, "formpart_align_to_top") );
 	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("To Bottom"), "aobottom", 0, "formpart_align_to_bottom") );
 	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("To Grid"), "aopos2grid", 0, "formpart_align_to_grid") );
 
-	action = createSharedAction(Kexi::DesignViewMode, i18n("Adjust Widgets Size"), "aogrid", 0, "formpart_adjust_size_menu", "KActionMenu");
-	menu = static_cast<KActionMenu*>(action);
+	action = createSharedAction(Kexi::DesignViewMode, i18n("Adjust Widgets Size"), "aogrid", 0, "formpart_adjust_size_menu", "TDEActionMenu");
+	menu = static_cast<TDEActionMenu*>(action);
 	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("To Fit"), "aofit", 0, "formpart_adjust_to_fit") );
 	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("To Grid"), "aogrid", 0, "formpart_adjust_size_grid") );
 	menu->insert( createSharedAction(Kexi::DesignViewMode, i18n("To Shortest"), "aoshortest", 0, "formpart_adjust_height_small") );
@@ -501,7 +501,7 @@ void KexiFormPart::setupCustomPropertyPanelTabs(KTabWidget *tab, KexiMainWindow*
 	KexiProject *prj = mainWin->project();
 	d->dataSourcePage->setProject(prj);
 
-	tab->addTab( d->dataSourcePage, SmallIconSet("database"), "");
+	tab->addTab( d->dataSourcePage, SmallIconSet("application-vnd.oasis.opendocument.database"), "");
 	tab->setTabToolTip( d->dataSourcePage, i18n("Data Source"));
 
 	tab->addTab( d->objectTreeView, SmallIconSet("widgets"), "");
