@@ -42,13 +42,13 @@
 #include <tqfontmetrics.h>
 #include <tqtooltip.h>
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kdebug.h>
 #include <kdialogbase.h>
-#include <kfiledialog.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kglobalsettings.h>
+#include <tdefiledialog.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdeglobalsettings.h>
 #include <kiconloader.h>
 #include <kcharsets.h>
 #include <knuminput.h>
@@ -72,7 +72,7 @@
 #include "kexicsvwidgets.h"
 
 #ifdef TQ_WS_WIN
-#include <krecentdirs.h>
+#include <tderecentdirs.h>
 #include <windows.h>
 #endif
 
@@ -192,7 +192,7 @@ KexiCSVImportDialog::KexiCSVImportDialog( Mode mode, KexiMainWindow* mainWin,
 	setIcon(DesktopIcon(_IMPORT_ICON));
 	setSizeGripEnabled( TRUE );
 
-//	m_encoding = TQString::fromLatin1(KGlobal::locale()->encoding());
+//	m_encoding = TQString::fromLatin1(TDEGlobal::locale()->encoding());
 //	m_stripWhiteSpaceInTextValuesChecked = true;
 	m_file = 0;
 	m_inputStream = 0;
@@ -308,7 +308,7 @@ if ( m_mode == Clipboard )
 		TQStringList mimetypes( csvMimeTypes() );
 #ifdef TQ_WS_WIN
 		//! @todo remove
-		TQString recentDir = KGlobalSettings::documentPath();
+		TQString recentDir = TDEGlobalSettings::documentPath();
 		m_fname = TQFileDialog::getOpenFileName( 
 			KFileDialog::getStartURL(":CSVImportExport", recentDir).path(),
 			KexiUtils::fileDialogFilterStrings(mimetypes, false),
@@ -318,7 +318,7 @@ if ( m_mode == Clipboard )
 			KURL url;
 			url.setPath( m_fname );
 			if (url.isLocalFile())
-				KRecentDirs::add(":CSVImportExport", url.directory());
+				TDERecentDirs::add(":CSVImportExport", url.directory());
 		}
 #else
 		m_fname = KFileDialog::getOpenFileName(":CSVImportExport", mimetypes.join(" "), 
@@ -358,7 +358,7 @@ if ( m_mode == Clipboard )
 	}
 
 	if (m_mode==Clipboard) {
-		m_infoLbl->setIcon("editpaste");
+		m_infoLbl->setIcon("edit-paste");
 	}
 	//updateRowCountInfo();
 
@@ -667,7 +667,7 @@ tristate KexiCSVImportDialog::loadRows(TQString &field, int &row, int &column, i
 		m_file->at(0); //always seek at 0 because loadRows() is called many times
 		m_inputStream = new TQTextStream(m_file);
 		if (m_options.defaultEncodingExplicitySet) {
-			TQTextCodec *codec = KGlobal::charsets()->codecForName(m_options.encoding);
+			TQTextCodec *codec = TDEGlobal::charsets()->codecForName(m_options.encoding);
 			if (codec)
 				m_inputStream->setCodec(codec); //TQTextCodec::codecForName("CP1250"));
 		}
