@@ -35,12 +35,12 @@
 #include "kivio_layer.h"
 #include "kivio_stencil.h"
 
-#include <kactionclasses.h>
-#include <kpopupmenu.h>
+#include <tdeactionclasses.h>
+#include <tdepopupmenu.h>
 #include <kdebug.h>
 #include <KoZoomHandler.h>
 #include <KoPoint.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <KoGuides.h>
 #include "kivio_command.h"
 
@@ -52,16 +52,16 @@ SelectTool::SelectTool( KivioView* parent ) : Kivio::MouseTool(parent, "Selectio
 {
   view()->pluginManager()->setDefaultTool(this);
 
-  KShortcut selectShortCut(Key_Space);
+  TDEShortcut selectShortCut(Key_Space);
   selectShortCut.setSeq(1, TQKeySequence(Key_Escape));
-  m_selectAction = new KRadioAction(i18n("&Select"), "select", selectShortCut, actionCollection(), "select");
+  m_selectAction = new TDERadioAction(i18n("&Select"), "select", selectShortCut, actionCollection(), "select");
   connect(m_selectAction, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(setActivated(bool)));
 
-  m_textEditAction = new KAction(i18n("&Edit Text..."), "text", Key_F2,
+  m_textEditAction = new TDEAction(i18n("&Edit Text..."), "text", Key_F2,
                                  this, TQT_SLOT(editStencilText()), actionCollection(), "editText");
-  (void) new KAction(i18n("Format &Stencils && Connectors..."), 0, 0, TQT_TQOBJECT(view()), TQT_SLOT(stencilFormat()),
+  (void) new TDEAction(i18n("Format &Stencils && Connectors..."), 0, 0, TQT_TQOBJECT(view()), TQT_SLOT(stencilFormat()),
                           actionCollection(), "formatStencil");
-  m_arrowHeadAction = new KAction(i18n("Format &Arrowheads..."), 0, 0, TQT_TQOBJECT(view()), TQT_SLOT(arrowHeadFormat()),
+  m_arrowHeadAction = new TDEAction(i18n("Format &Arrowheads..."), 0, 0, TQT_TQOBJECT(view()), TQT_SLOT(arrowHeadFormat()),
                                   actionCollection(), "formatConnector");
 
   m_mode = stmNone;
@@ -1107,12 +1107,12 @@ void SelectTool::endResizing(const TQPoint&)
  */
 void SelectTool::showPopupMenu( const TQPoint &pos )
 {
-  KPopupMenu* menu = 0;
+  TDEPopupMenu* menu = 0;
 
   if(view()->activePage()->selectedStencils()->count() < 1) {
-    menu = static_cast<KPopupMenu*>(view()->factory()->container("PagePopup", view()));
+    menu = static_cast<TDEPopupMenu*>(view()->factory()->container("PagePopup", view()));
   } else {
-    menu = static_cast<KPopupMenu*>(view()->factory()->container("StencilPopup", view()));
+    menu = static_cast<TDEPopupMenu*>(view()->factory()->container("StencilPopup", view()));
     m_arrowHeadAction->setEnabled(view()->activePage()->checkForStencilTypeInSelection(kstConnector));
 
     if(view()->activePage()->checkForTextBoxesInSelection()) {
