@@ -28,8 +28,8 @@
 #include "kptschedule.h"
 
 #include <kdebug.h>
-#include <kglobal.h>
-#include <klocale.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
 
 namespace KPlato
 {
@@ -360,8 +360,8 @@ bool Resource::load(TQDomElement &element) {
     if (s != "")
         m_availableUntil = DateTime::fromString(s);
         
-    cost.normalRate = KGlobal::locale()->readMoney(element.attribute("normal-rate"));
-    cost.overtimeRate = KGlobal::locale()->readMoney(element.attribute("overtime-rate"));
+    cost.normalRate = TDEGlobal::locale()->readMoney(element.attribute("normal-rate"));
+    cost.overtimeRate = TDEGlobal::locale()->readMoney(element.attribute("overtime-rate"));
     return true;
 }
 
@@ -380,8 +380,8 @@ void Resource::save(TQDomElement &element) const {
     me.setAttribute("units", m_units);
     me.setAttribute("available-from", m_availableFrom.toString(Qt::ISODate));
     me.setAttribute("available-until", m_availableUntil.toString(Qt::ISODate));
-    me.setAttribute("normal-rate", KGlobal::locale()->formatMoney(cost.normalRate));
-    me.setAttribute("overtime-rate", KGlobal::locale()->formatMoney(cost.overtimeRate));
+    me.setAttribute("normal-rate", TDEGlobal::locale()->formatMoney(cost.normalRate));
+    me.setAttribute("overtime-rate", TDEGlobal::locale()->formatMoney(cost.overtimeRate));
 }
 
 bool Resource::isAvailable(Task */*task*/) {
