@@ -102,7 +102,7 @@ protected:
 class KPrDocument : public KoDocument
 {
     Q_OBJECT
-  TQ_OBJECT
+  
     TQ_PROPERTY( int maxRecentFiles READ maxRecentFiles )
     TQ_PROPERTY( int undoRedoLimit READ undoRedoLimit WRITE setUndoRedoLimit )
     TQ_PROPERTY( double indentValue READ getIndentValue WRITE setIndentValue )
@@ -313,7 +313,7 @@ class KPrDocument : public KoDocument
     }
 
     /**
-     * get custom kspell config
+     * get custom tdespell config
      */
 
     bool showStatusBar() const { return m_bShowStatusBar;}
