@@ -29,7 +29,7 @@
 
 #include "KPrGradient.h"
 #include "KoPointArray.h"
-#include <klocale.h>
+#include <tdelocale.h>
 #include <KoPoint.h>
 #include <KoSize.h>
 #include <KoRect.h>
