@@ -60,7 +60,7 @@
 #include <KoVariable.h>
 #include <KoGenStyles.h>
 #include <KoXmlWriter.h>
-#include <ktempfile.h>
+#include <tdetempfile.h>
 #include <tqbuffer.h>
 #include <tqregexp.h>
 #include <tqfile.h>
@@ -2330,12 +2330,12 @@ KPrObject* KPrPage::getObjectAt( const KoPoint &pos, bool withoutProtected ) con
     {
         o = it.toLast();
         while ( o ) {
-            if ( o != m_doc->footer() || 
-                 o != m_doc->header() || 
-                 ( m_bHasFooter && o == m_doc->footer() ) || 
+            if ( o != m_doc->footer() ||
+                 o != m_doc->header() ||
+                 ( m_bHasFooter && o == m_doc->footer() ) ||
                  ( m_bHasHeader && o == m_doc->header() ) )
             {
-                if ( ( o->isSelected() || i > 0 ) && 
+                if ( ( o->isSelected() || i > 0 ) &&
                        o->contains( pos ) && !( o->isProtect() && withoutProtected ) )
                     return o;
             }
@@ -2420,10 +2420,10 @@ KCommand *KPrPage::alignVertical(VerticalAlignmentType _type )
             KPrTextObject *obj = dynamic_cast<KPrTextObject *>(it.current());
             if ( obj  && !obj->isProtectContent())
             {
-                KPrChangeVerticalAlignmentCommand * cmd = new KPrChangeVerticalAlignmentCommand( i18n("ChangeQt::Vertical Alignment"),
+                KPrChangeVerticalAlignmentCommand * cmd = new KPrChangeVerticalAlignmentCommand( i18n("Change Vertical Alignment"),
                                                                                                  obj, obj->verticalAlignment(),_type, m_doc);
                 if ( !macro )
-                    macro = new KMacroCommand( i18n("ChangeQt::Vertical Alignment"));
+                    macro = new KMacroCommand( i18n("Change Vertical Alignment"));
                 macro->addCommand( cmd );
                 cmd->execute();
             }
