@@ -30,7 +30,7 @@
 #include "commands.h"
 #include <KoDocumentInfo.h>
 
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kprinter.h>
 #include <kdebug.h>
 
