@@ -114,7 +114,7 @@ TQDomElement KSpread::util_createElement( const TQString & tagName, const TQFont
     e.setAttribute( "underline", "yes" );
   if ( font.strikeOut() )
     e.setAttribute( "strikeout", "yes" );
-  //e.setAttribute( "charset", KGlobal::charsets()->name( font ) );
+  //e.setAttribute( "charset", TDEGlobal::charsets()->name( font ) );
 
   return e;
 }
@@ -157,11 +157,11 @@ TQFont KSpread::util_toFont( TQDomElement & element )
   /* Uncomment when charset is added to kspread_dlg_layout
      + save a document-global charset
      if ( element.hasAttribute( "charset" ) )
-       KGlobal::charsets()->setTQFont( f, element.attribute("charset") );
+       TDEGlobal::charsets()->setTQFont( f, element.attribute("charset") );
       else
   */
   // ######## Not needed anymore in 3.0?
-  //KGlobal::charsets()->setTQFont( f, KGlobal::locale()->charset() );
+  //TDEGlobal::charsets()->setTQFont( f, TDEGlobal::locale()->charset() );
 
   return f;
 }
@@ -1015,7 +1015,7 @@ bool KSpread::localReferenceAnchor( const TQString &_ref )
 }
 
 
-TQString KSpread::Oasis::decodeFormula(const TQString& expr, const KLocale* locale)
+TQString KSpread::Oasis::decodeFormula(const TQString& expr, const TDELocale* locale)
 {
   // parsing state
   enum { Start, InNumber, InString, InIdentifier, InReference, InSheetName } state;
@@ -1208,11 +1208,11 @@ TQString KSpread::Oasis::decodeFormula(const TQString& expr, const KLocale* loca
   return result;
 }
 
-/*TQString KSpread::Oasis::encodeFormula(const TQString& expr, const KLocale* locale)
+/*TQString KSpread::Oasis::encodeFormula(const TQString& expr, const TDELocale* locale)
 {
   // TODO move Cell::convertFormulaToOasisFormat to this point
   //expr = "not here yet";
   //Q_UNUSED(locale);
   kdDebug() << k_funcinfo << " not implemented"
-  qFatal(0);
+  tqFatal(0);
 }*/
