@@ -35,17 +35,17 @@
 #include <KoStoreDevice.h>
 #include <KoXmlWriter.h>
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kdebug.h>
-#include <kdeversion.h>
-#include <kfileitem.h>
+#include <tdeversion.h>
+#include <tdefileitem.h>
 #include <kiconloader.h>
-#include <kio/job.h>
-#include <kio/netaccess.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdeio/job.h>
+#include <tdeio/netaccess.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <kmimetype.h>
-#include <kparts/partmanager.h>
+#include <tdeparts/partmanager.h>
 #include <kprinter.h>
 #include <ksavefile.h>
 
@@ -112,7 +112,7 @@ public:
     {
         m_confirmNonNativeSave[0] = true;
         m_confirmNonNativeSave[1] = true;
-        if ( KGlobal::locale()->measureSystem() == KLocale::Imperial ) {
+        if ( TDEGlobal::locale()->measureSystem() == TDELocale::Imperial ) {
             m_unit = KoUnit::U_INCH;
         } else {
             m_unit = KoUnit::U_CM;
@@ -168,9 +168,9 @@ public:
     KoViewWrapperWidget( TQWidget *parent, const char *name )
         : TQWidget( parent, name )
     {
-        KGlobal::locale()->insertCatalogue("koffice");
+        TDEGlobal::locale()->insertCatalogue("koffice");
         // Tell the iconloader about share/apps/koffice/icons
-        KGlobal::iconLoader()->addAppDir("koffice");
+        TDEGlobal::iconLoader()->addAppDir("koffice");
         m_view = 0L;
         // Avoid warning from KParts - we'll have the KoView as focus proxy anyway
         setFocusPolicy( TQ_ClickFocus );
@@ -264,11 +264,15 @@ KoDocument::KoDocument( TQWidget * parentWidget, const char *widgetName, TQObjec
 
     // A way to 'fix' the job's window, since we have no widget known to KParts
     if ( !singleViewMode )
-        connect( this, TQT_SIGNAL( started( KIO::Job* ) ), TQT_SLOT( slotStarted( KIO::Job* ) ) );
+        connect( this, TQT_SIGNAL( started( TDEIO::Job* ) ), TQT_SLOT( slotStarted( TDEIO::Job* ) ) );
 }
 
 KoDocument::~KoDocument()
 {
+    if (!d) {
+        return;
+    }
+
     d->m_autoSaveTimer.stop();
 
     TQPtrListIterator<KoDocumentChild> childIt( d->m_children );
@@ -288,12 +292,12 @@ KoDocument::~KoDocument()
     d->m_children.setAutoDelete( true );
     d->m_children.clear();
 
-    d->m_shells.setAutoDelete( true );
     d->m_shells.clear();
 
     delete d->m_dcopObject;
     delete d->filterManager;
     delete d;
+    d=0L;
     s_documentList->removeRef(this);
     // last one?
     if(s_documentList->isEmpty()) {
@@ -393,8 +397,8 @@ bool KoDocument::saveFile()
         if ( url().isLocalFile() )
             KSaveFile::backupFile( url().path(), d->m_backupPath );
         else {
-            KIO::UDSEntry entry;
-            if ( KIO::NetAccess::stat( url(), entry, shells().current() ) ) { // this file exists => backup
+            TDEIO::UDSEntry entry;
+            if ( TDEIO::NetAccess::stat( url(), entry, shells().current() ) ) { // this file exists => backup
                 emit sigStatusBarMessage( i18n("Making backup...") );
                 KURL backup;
                 if ( d->m_backupPath.isEmpty())
@@ -404,7 +408,7 @@ bool KoDocument::saveFile()
                 backup.setPath( backup.path() + TQString::fromLatin1("~") );
                 KFileItem item( entry, url() );
                 Q_ASSERT( item.name() == url().fileName() );
-                KIO::NetAccess::file_copy( url(), backup, item.permissions(), true /*overwrite*/, false /*resume*/, shells().current() );
+                TDEIO::NetAccess::file_copy( url(), backup, item.permissions(), true /*overwrite*/, false /*resume*/, shells().current() );
             }
         }
     }
@@ -557,10 +561,10 @@ void KoDocument::slotAutoSave()
     }
 }
 
-KAction *KoDocument::action( const TQDomElement &element ) const
+TDEAction *KoDocument::action( const TQDomElement &element ) const
 {
     // First look in the document itself
-    KAction* act = KParts::ReadWritePart::action( element );
+    TDEAction* act = KParts::ReadWritePart::action( element );
     if ( act )
         return act;
 
@@ -1268,7 +1272,7 @@ TQString KoDocument::autoSaveFile( const TQString & path ) const
 
     // Using the extension allows to avoid relying on the mime magic when opening
     KMimeType::Ptr mime = KMimeType::mimeType( nativeFormatMimeType() );
-    TQString extension = mime->property( "X-KDE-NativeExtension" ).toString();
+    TQString extension = mime->property( "X-TDE-NativeExtension" ).toString();
     if ( path.isEmpty() )
     {
         // Never saved? Use a temp file in $HOME then
@@ -2196,7 +2200,7 @@ TQCString KoDocument::nativeFormatMimeType() const
     KService::Ptr service = const_cast<KoDocument *>(this)->nativeService();
     if ( !service )
         return TQCString();
-    TQCString nativeMimeType = service->property( "X-KDE-NativeMimeType" ).toString().latin1();
+    TQCString nativeMimeType = service->property( "X-TDE-NativeMimeType" ).toString().latin1();
     if ( nativeMimeType.isEmpty() ) {
         // shouldn't happen, let's find out why it happened
         if ( !service->serviceTypes().contains( "KOfficePart" ) )
@@ -2212,12 +2216,12 @@ TQCString KoDocument::nativeOasisMimeType() const
     KService::Ptr service = const_cast<KoDocument *>(this)->nativeService();
     if ( !service )
         return TQCString();
-    return service->property( "X-KDE-NativeOasisMimeType" ).toString().latin1();
+    return service->property( "X-TDE-NativeOasisMimeType" ).toString().latin1();
 }
 
 
 //static
-KService::Ptr KoDocument::readNativeService( KInstance *instance )
+KService::Ptr KoDocument::readNativeService( TDEInstance *instance )
 {
     TQString instname = instance ? instance->instanceName() : kapp->instanceName();
 
@@ -2241,13 +2245,13 @@ KService::Ptr KoDocument::readNativeService( KInstance *instance )
     return service;
 }
 
-TQCString KoDocument::readNativeFormatMimeType( KInstance *instance ) //static
+TQCString KoDocument::readNativeFormatMimeType( TDEInstance *instance ) //static
 {
     KService::Ptr service = readNativeService( instance );
     if ( !service )
         return TQCString();
 
-    if ( service->property( "X-KDE-NativeMimeType" ).toString().isEmpty() )
+    if ( service->property( "X-TDE-NativeMimeType" ).toString().isEmpty() )
     {
         // It may be that the servicetype "KOfficePart" is missing, which leads to this property not being known
         if ( KServiceType::serviceType( "KOfficePart" ) == 0L )
@@ -2255,19 +2259,19 @@ TQCString KoDocument::readNativeFormatMimeType( KInstance *instance ) //static
         else {
             TQString instname = instance ? instance->instanceName() : kapp->instanceName();
             if ( instname != "koshell" ) // hack for koshell
-                kdWarning(30003) << service->desktopEntryPath() << ": no X-KDE-NativeMimeType entry!" << endl;
+                kdWarning(30003) << service->desktopEntryPath() << ": no X-TDE-NativeMimeType entry!" << endl;
         }
     }
 
-    return service->property( "X-KDE-NativeMimeType" ).toString().latin1();
+    return service->property( "X-TDE-NativeMimeType" ).toString().latin1();
 }
 
-TQStringList KoDocument::readExtraNativeMimeTypes( KInstance *instance ) //static
+TQStringList KoDocument::readExtraNativeMimeTypes( TDEInstance *instance ) //static
 {
     KService::Ptr service = readNativeService( instance );
     if ( !service )
         return TQStringList();
-    return service->property( "X-KDE-ExtraNativeMimeTypes" ).toStringList();
+    return service->property( "X-TDE-ExtraNativeMimeTypes" ).toStringList();
 }
 
 void KoDocument::setupXmlReader( TQXmlSimpleReader& reader, bool namespaceProcessing )
@@ -2302,7 +2306,7 @@ TQStringList KoDocument::extraNativeMimeTypes() const
     KService::Ptr service = const_cast<KoDocument *>(this)->nativeService();
     if ( !service ) // can't happen
         return lst;
-    return service->property( "X-KDE-ExtraNativeMimeTypes" ).toStringList();
+    return service->property( "X-TDE-ExtraNativeMimeTypes" ).toStringList();
 }
 
 int KoDocument::supportedSpecialFormats() const
@@ -2485,7 +2489,7 @@ bool KoDocument::hasExternURL() const
     return !url().protocol().isEmpty() && url().protocol() != STORE_PROTOCOL && url().protocol() != INTERNAL_PROTOCOL;
 }
 
-void KoDocument::slotStarted( KIO::Job* job )
+void KoDocument::slotStarted( TDEIO::Job* job )
 {
     if ( job )
     {
@@ -2545,7 +2549,7 @@ TQString KoDocument::unitName() const
 void KoDocument::showStartUpWidget( KoMainWindow* parent, bool alwaysShow )
 {
     if(!alwaysShow) {
-        KConfigGroup cfgGrp( instance()->config(), "TemplateChooserDialog" );
+        TDEConfigGroup cfgGrp( instance()->config(), "TemplateChooserDialog" );
         TQString fullTemplateName = cfgGrp.readPathEntry( "AlwaysUseTemplate" );
 
         if( !fullTemplateName.isEmpty() ) {
@@ -2600,7 +2604,7 @@ void KoDocument::startCustomDocument() {
     deleteOpenPane();
 }
 
-KoOpenPane* KoDocument::createOpenPane( TQWidget* parent, KInstance* instance,
+KoOpenPane* KoDocument::createOpenPane( TQWidget* parent, TDEInstance* instance,
                                         const TQString& templateType )
 {
     KoOpenPane* openPane = new KoOpenPane( parent, instance, templateType );
