@@ -40,17 +40,17 @@
 #include <tqvbox.h>
 #include <tqdatetime.h>
 
-#include <kabc/addressee.h>
-#include <kabc/stdaddressbook.h>
-#include <kdeversion.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdeabc/addressee.h>
+#include <tdeabc/stdaddressbook.h>
+#include <tdeversion.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <ktar.h>
 #include <kdebug.h>
-#include <ktempfile.h>
+#include <tdetempfile.h>
 #include <kmimetype.h>
 #include <tqlayout.h>
-#include <klistview.h>
+#include <tdelistview.h>
 #include <tqgrid.h>
 #include <tqmap.h>
 #include <kfilterdev.h>
@@ -58,7 +58,7 @@
 #include <ktextedit.h>
 #include <kiconloader.h>
 #include <kpushbutton.h>
-#include <klocale.h>
+#include <tdelocale.h>
 
 class KoDocumentInfoDlg::KoDocumentInfoDlgPrivate
 {
@@ -134,13 +134,13 @@ KDialogBase *KoDocumentInfoDlg::dialog() const
 
 void KoDocumentInfoDlg::loadFromKABC()
 {
-  KABC::StdAddressBook *ab = static_cast<KABC::StdAddressBook*>
-                             ( KABC::StdAddressBook::self() );
+  TDEABC::StdAddressBook *ab = static_cast<TDEABC::StdAddressBook*>
+                             ( TDEABC::StdAddressBook::self() );
 
   if ( !ab )
     return;
 
-  KABC::Addressee addr = ab->whoAmI();
+  TDEABC::Addressee addr = ab->whoAmI();
   if ( addr.isEmpty() )
   {
     KMessageBox::sorry( 0L, i18n( "No personal contact data set, please use the option \
@@ -155,15 +155,15 @@ void KoDocumentInfoDlg::loadFromKABC()
   d->m_authorWidget->leCompany->setText( addr.organization() );
   d->m_authorWidget->leEmail->setText( addr.preferredEmail() );
 
-  KABC::PhoneNumber phone = addr.phoneNumber( KABC::PhoneNumber::Home );
+  TDEABC::PhoneNumber phone = addr.phoneNumber( TDEABC::PhoneNumber::Home );
   d->m_authorWidget->leTelephoneHome->setText( phone.number() );
-  phone = addr.phoneNumber( KABC::PhoneNumber::Work );
+  phone = addr.phoneNumber( TDEABC::PhoneNumber::Work );
   d->m_authorWidget->leTelephoneWork->setText( phone.number() );
 
-  phone = addr.phoneNumber( KABC::PhoneNumber::Fax );
+  phone = addr.phoneNumber( TDEABC::PhoneNumber::Fax );
   d->m_authorWidget->leFax->setText( phone.number() );
 
-  KABC::Address a = addr.address( KABC::Address::Home );
+  TDEABC::Address a = addr.address( TDEABC::Address::Home );
   d->m_authorWidget->leCountry->setText( a.country() );
   d->m_authorWidget->lePostalCode->setText( a.postalCode() );
   d->m_authorWidget->leCity->setText( a.locality() );
@@ -191,7 +191,7 @@ void KoDocumentInfoDlg::deleteInfo()
 
 void KoDocumentInfoDlg::resetMetaData()
 {
-  TQString s = KGlobal::locale()->formatDateTime( TQDateTime::currentDateTime() );
+  TQString s = TDEGlobal::locale()->formatDateTime( TQDateTime::currentDateTime() );
   d->m_aboutWidget->labelCreated->setText( s + ", " + d->m_info->creator() );
   d->m_aboutWidget->labelModified->setText( "" );
   d->m_aboutWidget->labelRevision->setText( "0" );
@@ -202,9 +202,9 @@ void KoDocumentInfoDlg::addAuthorPage( KoDocumentInfoAuthor *authorInfo )
 {
   TQVBox *page = d->m_dialog->addVBoxPage( i18n( "Author" ) );
   d->m_authorWidget = new KoDocumentInfoAuthorWidget( page );
-  d->m_authorWidget->labelAuthor->setPixmap( KGlobal::iconLoader()->loadIcon( "personal", KIcon::Desktop, 48 ) );
-  d->m_authorWidget->pbLoadKABC->setIconSet( TQIconSet( KGlobal::iconLoader()->loadIcon( "kaddressbook", KIcon::Small ) ) );
-  d->m_authorWidget->pbDelete->setIconSet( TQIconSet( KGlobal::iconLoader()->loadIcon( "eraser", KIcon::Small ) ) );
+  d->m_authorWidget->labelAuthor->setPixmap( TDEGlobal::iconLoader()->loadIcon( "preferences-desktop-personal", TDEIcon::Desktop, 48 ) );
+  d->m_authorWidget->pbLoadKABC->setIconSet( TQIconSet( TDEGlobal::iconLoader()->loadIcon( "kaddressbook", TDEIcon::Small ) ) );
+  d->m_authorWidget->pbDelete->setIconSet( TQIconSet( TDEGlobal::iconLoader()->loadIcon( "eraser", TDEIcon::Small ) ) );
 
   d->m_authorWidget->leFullName->setText( authorInfo->fullName() );
   d->m_authorWidget->leInitial->setText( authorInfo->initial() );
@@ -256,13 +256,13 @@ void KoDocumentInfoDlg::addAboutPage( KoDocumentInfoAbout *aboutInfo )
 {
   TQVBox *page = d->m_dialog->addVBoxPage( i18n( "General" ) );
   d->m_aboutWidget = new KoDocumentInfoAboutWidget( page );
-  d->m_aboutWidget->pbReset->setIconSet( TQIconSet( KGlobal::iconLoader()->loadIcon( "reload", KIcon::Small ) ) );
+  d->m_aboutWidget->pbReset->setIconSet( TQIconSet( TDEGlobal::iconLoader()->loadIcon( "reload", TDEIcon::Small ) ) );
   KoDocument* doc = dynamic_cast< KoDocument* >( d->m_info->parent() );
   if ( doc )
   {
     d->m_aboutWidget->leDocFile->setText( doc->file() );
     d->m_aboutWidget->labelType->setText( KMimeType::mimeType( doc->mimeType() )->comment() );
-    d->m_aboutWidget->pixmapLabel->setPixmap( KMimeType::mimeType( doc->mimeType() )->pixmap( KIcon::Desktop, 48 ) );
+    d->m_aboutWidget->pixmapLabel->setPixmap( KMimeType::mimeType( doc->mimeType() )->pixmap( TDEIcon::Desktop, 48 ) );
   }
   if ( aboutInfo->creationDate() != TQString() )
     d->m_aboutWidget->labelCreated->setText( aboutInfo->creationDate() + ", " + aboutInfo->initialCreator() );
@@ -301,8 +301,8 @@ void KoDocumentInfoDlg::addUserMetadataPage( KoDocumentInfoUserMetadata *userMet
     {
         TQString name = it.key();
         TQString value = it.data();
-        KListViewItem* it = new KListViewItem( d->m_metaWidget->metaListView, name, value );
-        it->setPixmap( 0, KGlobal::iconLoader()->loadIcon( "text", KIcon::Small ) );
+        TDEListViewItem* it = new TDEListViewItem( d->m_metaWidget->metaListView, name, value );
+        it->setPixmap( 0, TDEGlobal::iconLoader()->loadIcon( "text", TDEIcon::Small ) );
     }
 }
 
@@ -346,8 +346,8 @@ void KoDocumentInfoDlg::save( KoDocumentInfoAuthor *authorInfo )
   authorInfo->setStreet( d->m_authorWidget->leStreet->text() );
   authorInfo->setPosition( d->m_authorWidget->leAuthorPosition->text() );
 
-  KConfig* config = KoGlobal::kofficeConfig();
-  KConfigGroupSaver cgs( config, "Author" );
+  TDEConfig* config = KoGlobal::kofficeConfig();
+  TDEConfigGroupSaver cgs( config, "Author" );
   config->writeEntry("telephone", d->m_authorWidget->leTelephoneHome->text());
   config->writeEntry("telephone-work", d->m_authorWidget->leTelephoneWork->text());
   config->writeEntry("fax", d->m_authorWidget->leFax->text());
